@@ -2,7 +2,7 @@ package Rarbg::torrentapi;
 
 use strict;
 use 5.008_005;
-our $VERSION = 'v0.1.3';
+our $VERSION = 'v0.1.4';
 use LWP::UserAgent;
 use JSON;
 use Carp;
@@ -40,7 +40,7 @@ has ranked => (
     default => 0
 );
 
-has _mode => (
+has mode => (
     is      => 'rw',
     isa     => 'Str',
     default => 'list'
@@ -137,7 +137,7 @@ foreach my $method (qw/list search/) {
             foreach my $key ( keys %{$args} ) {
                 $self->$key( $args->{$key} );
             }
-            $self->_mode("$method");
+            $self->mode("$method");
             return $self->_make_request;
         }
     );
